summaryrefslogtreecommitdiffstats
path: root/kate/plugins/kdatatool/kate_kdatatool.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kate/plugins/kdatatool/kate_kdatatool.cpp
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kate/plugins/kdatatool/kate_kdatatool.cpp')
-rw-r--r--kate/plugins/kdatatool/kate_kdatatool.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kate/plugins/kdatatool/kate_kdatatool.cpp b/kate/plugins/kdatatool/kate_kdatatool.cpp
index 5a0308b50..11cd645b7 100644
--- a/kate/plugins/kdatatool/kate_kdatatool.cpp
+++ b/kate/plugins/kdatatool/kate_kdatatool.cpp
@@ -108,7 +108,7 @@ void KDataToolPluginView::aboutToShow()
if ( selectionInterface(m_view->document())->hasSelection() )
{
word = selectionInterface(m_view->document())->selection();
- if ( word.tqfind(' ') == -1 && word.tqfind('\t') == -1 && word.tqfind('\n') == -1 )
+ if ( word.find(' ') == -1 && word.find('\t') == -1 && word.find('\n') == -1 )
m_singleWord = true;
else
m_singleWord = false;
@@ -123,7 +123,7 @@ void KDataToolPluginView::aboutToShow()
ci->cursorPositionReal(&line, &col);
TQString tmp_line = ei->textLine(line);
m_wordUnderCursor = "";
// tqfind begin of word:
m_singleWord_start = 0;
for(int i = col; i >= 0; i--) {
TQChar ch = tmp_line.at(i);
@@ -134,7 +134,7 @@ void KDataToolPluginView::aboutToShow()
}
m_wordUnderCursor = ch + m_wordUnderCursor;
}
// tqfind end of word:
m_singleWord_end = tmp_line.length();
for(uint i = col+1; i < tmp_line.length(); i++) {
TQChar ch = tmp_line.at(i);
@@ -206,7 +206,7 @@ void KDataToolPluginView::slotToolActivated( const KDataToolInfo &info, const TQ
TQString datatype = "TQString";
// If unsupported (and if we have a single word indeed), try application/x-singleword
- if ( !info.mimeTypes().tqcontains( mimetype ) && m_singleWord )
+ if ( !info.mimeTypes().contains( mimetype ) && m_singleWord )
mimetype = "application/x-singleword";
kdDebug() << "Running tool with datatype=" << datatype << " mimetype=" << mimetype << endl;
@@ -227,7 +227,7 @@ void KDataToolPluginView::slotToolActivated( const KDataToolInfo &info, const TQ
si->setSelection(m_singleWord_line, m_singleWord_start, m_singleWord_line, m_singleWord_end);
}
- // tqreplace selection with 'text'
+ // replace selection with 'text'
selectionInterface(m_view->document())->removeSelectedText();
viewCursorInterface(m_view)->cursorPositionReal(&line, &col);
editInterface(m_view->document())->insertText(line, col, text);
@@ -123,7 +123,7 @@ void KDataToolPluginView::aboutToShow()
TQString tmp_line = ei->textLine(line);
m_wordUnderCursor = "";
- // tqfind begin of word:
+ // find begin of word:
m_singleWord_start = 0;
for(int i = col; i >= 0; i--) {
@@ -134,7 +134,7 @@ void KDataToolPluginView::aboutToShow()
m_wordUnderCursor = ch + m_wordUnderCursor;
}
- // tqfind end of word:
+ // find end of word:
m_singleWord_end = tmp_line.length();
for(uint i = col+1; i < tmp_line.length(); i++) {